# coding: utf-8

"""
    Strava API v3

    Strava API  # noqa: E501

    OpenAPI spec version: 3.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from swagger_client.models.activity_type import ActivityType  # noqa: F401,E501


class UpdatableActivity(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'commute': 'bool',
        'trainer': 'bool',
        'description': 'str',
        'name': 'str',
        'type': 'ActivityType',
        'gear_id': 'str'
    }

    attribute_map = {
        'commute': 'commute',
        'trainer': 'trainer',
        'description': 'description',
        'name': 'name',
        'type': 'type',
        'gear_id': 'gear_id'
    }

    def __init__(self, commute=None, trainer=None, description=None, name=None, type=None, gear_id=None):  # noqa: E501
        """UpdatableActivity - a model defined in Swagger"""  # noqa: E501

        self._commute = None
        self._trainer = None
        self._description = None
        self._name = None
        self._type = None
        self._gear_id = None
        self.discriminator = None

        if commute is not None:
            self.commute = commute
        if trainer is not None:
            self.trainer = trainer
        if description is not None:
            self.description = description
        if name is not None:
            self.name = name
        if type is not None:
            self.type = type
        if gear_id is not None:
            self.gear_id = gear_id

    @property
    def commute(self):
        """Gets the commute of this UpdatableActivity.  # noqa: E501

        Whether this activity is a commute  # noqa: E501

        :return: The commute of this UpdatableActivity.  # noqa: E501
        :rtype: bool
        """
        return self._commute

    @commute.setter
    def commute(self, commute):
        """Sets the commute of this UpdatableActivity.

        Whether this activity is a commute  # noqa: E501

        :param commute: The commute of this UpdatableActivity.  # noqa: E501
        :type: bool
        """

        self._commute = commute

    @property
    def trainer(self):
        """Gets the trainer of this UpdatableActivity.  # noqa: E501

        Whether this activity was recorded on a training machine  # noqa: E501

        :return: The trainer of this UpdatableActivity.  # noqa: E501
        :rtype: bool
        """
        return self._trainer

    @trainer.setter
    def trainer(self, trainer):
        """Sets the trainer of this UpdatableActivity.

        Whether this activity was recorded on a training machine  # noqa: E501

        :param trainer: The trainer of this UpdatableActivity.  # noqa: E501
        :type: bool
        """

        self._trainer = trainer

    @property
    def description(self):
        """Gets the description of this UpdatableActivity.  # noqa: E501

        The description of the activity  # noqa: E501

        :return: The description of this UpdatableActivity.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this UpdatableActivity.

        The description of the activity  # noqa: E501

        :param description: The description of this UpdatableActivity.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def name(self):
        """Gets the name of this UpdatableActivity.  # noqa: E501

        The name of the activity  # noqa: E501

        :return: The name of this UpdatableActivity.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UpdatableActivity.

        The name of the activity  # noqa: E501

        :param name: The name of this UpdatableActivity.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def type(self):
        """Gets the type of this UpdatableActivity.  # noqa: E501


        :return: The type of this UpdatableActivity.  # noqa: E501
        :rtype: ActivityType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this UpdatableActivity.


        :param type: The type of this UpdatableActivity.  # noqa: E501
        :type: ActivityType
        """

        self._type = type

    @property
    def gear_id(self):
        """Gets the gear_id of this UpdatableActivity.  # noqa: E501

        Identifier for the gear associated with the activity. ‘none’ clears gear from activity  # noqa: E501

        :return: The gear_id of this UpdatableActivity.  # noqa: E501
        :rtype: str
        """
        return self._gear_id

    @gear_id.setter
    def gear_id(self, gear_id):
        """Sets the gear_id of this UpdatableActivity.

        Identifier for the gear associated with the activity. ‘none’ clears gear from activity  # noqa: E501

        :param gear_id: The gear_id of this UpdatableActivity.  # noqa: E501
        :type: str
        """

        self._gear_id = gear_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdatableActivity, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdatableActivity):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
