from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from swagger_client.api.activities_api import ActivitiesApi
from swagger_client.api.athletes_api import AthletesApi
from swagger_client.api.clubs_api import ClubsApi
from swagger_client.api.gears_api import GearsApi
from swagger_client.api.routes_api import RoutesApi
from swagger_client.api.running_races_api import RunningRacesApi
from swagger_client.api.segment_efforts_api import SegmentEffortsApi
from swagger_client.api.segments_api import SegmentsApi
from swagger_client.api.streams_api import StreamsApi
from swagger_client.api.uploads_api import UploadsApi
