# coding: utf-8

"""
    Strava API v3

    Strava API  # noqa: E501

    OpenAPI spec version: 3.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SummaryGear(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'resource_state': 'int',
        'primary': 'bool',
        'name': 'str',
        'distance': 'float'
    }

    attribute_map = {
        'id': 'id',
        'resource_state': 'resource_state',
        'primary': 'primary',
        'name': 'name',
        'distance': 'distance'
    }

    def __init__(self, id=None, resource_state=None, primary=None, name=None, distance=None):  # noqa: E501
        """SummaryGear - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._resource_state = None
        self._primary = None
        self._name = None
        self._distance = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if resource_state is not None:
            self.resource_state = resource_state
        if primary is not None:
            self.primary = primary
        if name is not None:
            self.name = name
        if distance is not None:
            self.distance = distance

    @property
    def id(self):
        """Gets the id of this SummaryGear.  # noqa: E501

        The gear's unique identifier.  # noqa: E501

        :return: The id of this SummaryGear.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SummaryGear.

        The gear's unique identifier.  # noqa: E501

        :param id: The id of this SummaryGear.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def resource_state(self):
        """Gets the resource_state of this SummaryGear.  # noqa: E501

        Resource state, indicates level of detail. Possible values: 2 -> \"summary\", 3 -> \"detail\"  # noqa: E501

        :return: The resource_state of this SummaryGear.  # noqa: E501
        :rtype: int
        """
        return self._resource_state

    @resource_state.setter
    def resource_state(self, resource_state):
        """Sets the resource_state of this SummaryGear.

        Resource state, indicates level of detail. Possible values: 2 -> \"summary\", 3 -> \"detail\"  # noqa: E501

        :param resource_state: The resource_state of this SummaryGear.  # noqa: E501
        :type: int
        """

        self._resource_state = resource_state

    @property
    def primary(self):
        """Gets the primary of this SummaryGear.  # noqa: E501

        Whether this gear's is the owner's default one.  # noqa: E501

        :return: The primary of this SummaryGear.  # noqa: E501
        :rtype: bool
        """
        return self._primary

    @primary.setter
    def primary(self, primary):
        """Sets the primary of this SummaryGear.

        Whether this gear's is the owner's default one.  # noqa: E501

        :param primary: The primary of this SummaryGear.  # noqa: E501
        :type: bool
        """

        self._primary = primary

    @property
    def name(self):
        """Gets the name of this SummaryGear.  # noqa: E501

        The gear's name.  # noqa: E501

        :return: The name of this SummaryGear.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SummaryGear.

        The gear's name.  # noqa: E501

        :param name: The name of this SummaryGear.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def distance(self):
        """Gets the distance of this SummaryGear.  # noqa: E501

        The distance logged with this gear.  # noqa: E501

        :return: The distance of this SummaryGear.  # noqa: E501
        :rtype: float
        """
        return self._distance

    @distance.setter
    def distance(self, distance):
        """Sets the distance of this SummaryGear.

        The distance logged with this gear.  # noqa: E501

        :param distance: The distance of this SummaryGear.  # noqa: E501
        :type: float
        """

        self._distance = distance

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SummaryGear, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SummaryGear):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
