# coding: utf-8

"""
    Strava API v3

    Strava API  # noqa: E501

    OpenAPI spec version: 3.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from swagger_client.models.summary_athlete import SummaryAthlete  # noqa: F401,E501


class Comment(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'activity_id': 'int',
        'text': 'str',
        'athlete': 'SummaryAthlete',
        'created_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'activity_id': 'activity_id',
        'text': 'text',
        'athlete': 'athlete',
        'created_at': 'created_at'
    }

    def __init__(self, id=None, activity_id=None, text=None, athlete=None, created_at=None):  # noqa: E501
        """Comment - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._activity_id = None
        self._text = None
        self._athlete = None
        self._created_at = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if activity_id is not None:
            self.activity_id = activity_id
        if text is not None:
            self.text = text
        if athlete is not None:
            self.athlete = athlete
        if created_at is not None:
            self.created_at = created_at

    @property
    def id(self):
        """Gets the id of this Comment.  # noqa: E501

        The unique identifier of this comment  # noqa: E501

        :return: The id of this Comment.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Comment.

        The unique identifier of this comment  # noqa: E501

        :param id: The id of this Comment.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def activity_id(self):
        """Gets the activity_id of this Comment.  # noqa: E501

        The identifier of the activity this comment is related to  # noqa: E501

        :return: The activity_id of this Comment.  # noqa: E501
        :rtype: int
        """
        return self._activity_id

    @activity_id.setter
    def activity_id(self, activity_id):
        """Sets the activity_id of this Comment.

        The identifier of the activity this comment is related to  # noqa: E501

        :param activity_id: The activity_id of this Comment.  # noqa: E501
        :type: int
        """

        self._activity_id = activity_id

    @property
    def text(self):
        """Gets the text of this Comment.  # noqa: E501

        The content of the comment  # noqa: E501

        :return: The text of this Comment.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this Comment.

        The content of the comment  # noqa: E501

        :param text: The text of this Comment.  # noqa: E501
        :type: str
        """

        self._text = text

    @property
    def athlete(self):
        """Gets the athlete of this Comment.  # noqa: E501


        :return: The athlete of this Comment.  # noqa: E501
        :rtype: SummaryAthlete
        """
        return self._athlete

    @athlete.setter
    def athlete(self, athlete):
        """Sets the athlete of this Comment.


        :param athlete: The athlete of this Comment.  # noqa: E501
        :type: SummaryAthlete
        """

        self._athlete = athlete

    @property
    def created_at(self):
        """Gets the created_at of this Comment.  # noqa: E501

        The time at which this comment was created.  # noqa: E501

        :return: The created_at of this Comment.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Comment.

        The time at which this comment was created.  # noqa: E501

        :param created_at: The created_at of this Comment.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Comment, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Comment):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
