# coding: utf-8

"""
    Strava API v3

    Strava API  # noqa: E501

    OpenAPI spec version: 3.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RouteDirection(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'distance': 'float',
        'action': 'int',
        'name': 'str'
    }

    attribute_map = {
        'distance': 'distance',
        'action': 'action',
        'name': 'name'
    }

    def __init__(self, distance=None, action=None, name=None):  # noqa: E501
        """RouteDirection - a model defined in Swagger"""  # noqa: E501

        self._distance = None
        self._action = None
        self._name = None
        self.discriminator = None

        if distance is not None:
            self.distance = distance
        if action is not None:
            self.action = action
        if name is not None:
            self.name = name

    @property
    def distance(self):
        """Gets the distance of this RouteDirection.  # noqa: E501

        The distance in the route at which the action applies  # noqa: E501

        :return: The distance of this RouteDirection.  # noqa: E501
        :rtype: float
        """
        return self._distance

    @distance.setter
    def distance(self, distance):
        """Sets the distance of this RouteDirection.

        The distance in the route at which the action applies  # noqa: E501

        :param distance: The distance of this RouteDirection.  # noqa: E501
        :type: float
        """

        self._distance = distance

    @property
    def action(self):
        """Gets the action of this RouteDirection.  # noqa: E501

        The action of this direction  # noqa: E501

        :return: The action of this RouteDirection.  # noqa: E501
        :rtype: int
        """
        return self._action

    @action.setter
    def action(self, action):
        """Sets the action of this RouteDirection.

        The action of this direction  # noqa: E501

        :param action: The action of this RouteDirection.  # noqa: E501
        :type: int
        """

        self._action = action

    @property
    def name(self):
        """Gets the name of this RouteDirection.  # noqa: E501


        :return: The name of this RouteDirection.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this RouteDirection.


        :param name: The name of this RouteDirection.  # noqa: E501
        :type: str
        """

        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RouteDirection, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RouteDirection):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
